@@ -3,7 +3,7 @@
 // (Post Relational Database Management System)                      *   /\|  *
 //                                                                   *  /  \  *
 //                          Created:     20-Nov-98    K.A. Knizhnik  * / [] \ *
-//                          Last update: 10-Dec-98    K.A. Knizhnik  * GARRET *
+//                          Last update:  5-Oct-99    K.A. Knizhnik  * GARRET *
 //-------------------------------------------------------------------*--------*
 // Main header file
 //-------------------------------------------------------------------*--------*
@@ -11,12 +11,20 @@
 #ifndef __GIGABASE_H__
 #define __GIGABASE_H__
 
-#define GIGABASE_VERSION 109
+#define GIGABASE_MAJOR_VERSION 3
+#define GIGABASE_MINOR_VERSION 28
+#define GIGABASE_VERSION (GIGABASE_MAJOR_VERSION*100 + GIGABASE_MINOR_VERSION)
 
 #include "database.h"
 #include "array.h"
 #include "query.h"
 #include "cursor.h"
 #include "datetime.h"
+#include "blob.h"
+#include "container.h"
+
+#ifdef THROW_EXCEPTION_ON_ERROR
+#include "exception.h"
+#endif
 
 #endif
