@@ -11,18 +11,40 @@
 #ifndef __SYMTAB_H__
 #define __SYMTAB_H__
 
-class dbSymbolTable { 
-    struct HashTableItem { 
-	HashTableItem* next;
-	char*          str;
-	unsigned       hash;
-	int            tag;
+BEGIN_GIGABASE_NAMESPACE
+
+#ifndef CLONE_IDENTIFIERS
+#define GB_CLONE_ANY_IDENTIFIER false
+#else
+#define GB_CLONE_ANY_IDENTIFIER true
+#endif
+
+class GIGABASE_DLL_ENTRY dbSymbolTable {
+    struct HashTableItem {
+        HashTableItem* next;
+        char_t*        str;
+        unsigned       hash;
+        byte           tag;
+        byte           allocated;
+        
+        ~HashTableItem() { 
+            if (allocated) { 
+                delete[] str;
+            }
+        }
     };
-    static HashTableItem* hashTable[]; 
-   
-  public:    
-    static int add(char* &str, int tag,  bool allocate = true);
+    static HashTableItem* hashTable[];
+
+  public:
+    ~dbSymbolTable();
+    static dbSymbolTable instance;
+
+    static int add(char_t* &str, int tag, bool allocate = true);
+
+    static void cleanup();
 };
 
+END_GIGABASE_NAMESPACE
+
 #endif
 
